@@ -37,7 +37,7 @@ Implementation Notes
     `MCP3004`_, `MCP3002`_) for a list of available differential channel mappings.
 """
 
-__version__ = "1.4.12"
+__version__ = "1.4.13"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MCP3xxx.git"
 
 from adafruit_bus_device.spi_device import SPIDevice
@@ -53,7 +53,7 @@ class MCP3xxx:
     :param float ref_voltage: Voltage into (Vin) the ADC.
     """
 
-    def __init__(self, spi_bus, cs, ref_voltage=3.3):
+    def __init__(self, spi_bus, cs, ref_voltage=3.3):  # pylint: disable=invalid-name
         self._spi_device = SPIDevice(spi_bus, cs)
         self._out_buf = bytearray(3)
         self._in_buf = bytearray(3)
